import bpy
import bmesh
from bmesh import types

def main(context):
    for ob in context.scene.objects:
        print(ob)


class AdjacentSelection(bpy.types.Operator):
    """Tooltip"""
    bl_idname = "object.adjacent_selection"
    bl_label = "Adjacent Selection"

    @classmethod
    def poll(cls, context):
        return context.active_object is not None

    def execute(self, context):
        main(context)
        me = bpy.context.active_object.data
        bm = bmesh.from_edit_mesh(me)
        EDGE = 0

        vertSelect = bpy.context.tool_settings.mesh_select_mode[0]
        edgeSelect = bpy.context.tool_settings.mesh_select_mode[1]
        faceSelect = bpy.context.tool_settings.mesh_select_mode[2]

        if faceSelect:
            vListA = []
            for face in bm.faces:
                if face.select : vListA.append(face)

            vListB = []
            bpy.ops.mesh.select_more()
            for face in bm.faces:
                if face.select : vListB.append(face)

            bpy.ops.mesh.select_all(action='DESELECT')

            for face in vListB:
                if face not in vListA: face.select = True
        
        if edgeSelect or vertSelect:
            if edgeSelect : EDGE = 1
            vListA = []
            for v in bm.verts:
                if v.select : vListA.append(v)

            vListB = []
            bpy.ops.mesh.select_more()
            for v in bm.verts:
                if v.select : vListB.append(v)

            bpy.ops.mesh.select_all(action='DESELECT')

            for v in vListB:
                if v not in vListA: v.select = True 
            if EDGE == 1:
                bpy.context.tool_settings.mesh_select_mode = (True, False, False)
                bpy.context.tool_settings.mesh_select_mode = (False, True, False) 
        return {'FINISHED'}


def register():
    bpy.utils.register_class(AdjacentSelection)

    wm = bpy.context.window_manager
    km = wm.keyconfigs.addon.keymaps.new(name='3D View', space_type='VIEW_3D')
    kmi = km.keymap_items.new('object.adjacent_selection', 'Y', 'PRESS', ctrl=True)
    kmi.properties.total = 4
    addon_keymaps.append(km)	


def unregister():
    bpy.utils.unregister_class(AdjacentSelection)


if __name__ == "__main__":
    register()