import bpy
import bmesh
from bmesh import types

def main(context):
    for ob in context.scene.objects:
        print(ob)


class DeleteAuto(bpy.types.Operator):
    """Tooltip"""
    bl_idname = "object.delete_auto"
    bl_label = "Delete Auto"

    @classmethod
    def poll(cls, context):
        return context.active_object is not None

    def execute(self, context):
        main(context)
        vertSelect = bpy.context.tool_settings.mesh_select_mode[0]
        edgeSelect = bpy.context.tool_settings.mesh_select_mode[1]
        faceSelect = bpy.context.tool_settings.mesh_select_mode[2]


        me = bpy.context.active_object.data
        bm = bmesh.from_edit_mesh(me)


        if faceSelect: bpy.ops.mesh.delete(type='FACE')

        if edgeSelect:
            vListA = []
            for face in bm.edges: 
                if face.select : vListA.append(face)
    
            bpy.ops.mesh.loop_multi_select(ring=False)
    
            vListB = []
            for face in bm.edges: 
                if face.select : vListB.append(face) 
    
            bpy.ops.mesh.select_all(action='DESELECT')
            for edge in vListA: edge.select = True   

    
            if len(vListA) == len(vListB): 
                bpy.ops.mesh.delete_edgeloop()             
            else: 
                bpy.ops.mesh.dissolve_limited(angle_limit=3.14159)
           
        if vertSelect:
            vListA = []
            for face in bm.verts: 
                if face.select : vListA.append(face)
    
            bpy.ops.mesh.select_more()    
            vListB = []
            for face in bm.verts: 
                if face.select : vListB.append(face) 
    
            bpy.ops.mesh.select_all(action='DESELECT')    
            for edge in vListA: edge.select = True   

    
            if (len(vListA)+1) >= len(vListB): 
                bpy.ops.mesh.delete(type='VERT')       
            else: 
                bpy.ops.mesh.dissolve_mode() 
                
        return {'FINISHED'}


def register():
    bpy.utils.register_class(DeleteAuto)

    wm = bpy.context.window_manager
    km = wm.keyconfigs.addon.keymaps.new(name='3D View', space_type='VIEW_3D')
    kmi = km.keymap_items.new('object.delete_auto', 'Y', 'PRESS', alt=True)
    kmi.properties.total = 4
    addon_keymaps.append(km)	


def unregister():
    bpy.utils.unregister_class(DeleteAuto)


if __name__ == "__main__":
    register()